@@ -81,7 +81,7 @@ class MinutiaeNetWrapper:
         mnt_refined = []
 
         # ======= Verify using FineNet ============
-        if FINE_NET_PATH is not None:
+        if fine_net_path is not None:
             for idx_minu in range(mnt_nms.shape[0]):
                 try:
                     # Extract patch from image
